==> taskana-common-4.8.0-sources.jar: sql/db2/taskana_schema_update_4.3.0_to_4.8.0_db2.sql <==
-- this script updates the TASKANA database schema from version 4.3.0 to version 4.8.0.

SET SCHEMA %schemaName%;

INSERT INTO TASKANA_SCHEMA_VERSION (VERSION, CREATED) VALUES ('4.8.0', CURRENT_TIMESTAMP);

ALTER TABLE TASK ADD COLUMN RECEIVED TIMESTAMP NULL;
ALTER TABLE TASK ADD COLUMN MANUAL_PRIORITY INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_1 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_2 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_3 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_4 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_5 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_6 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_7 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_8 INT NULL;
CALL SYSPROC.ADMIN_CMD ('REORG TABLE TASK');

ALTER TABLE CONFIGURATION ADD COLUMN CUSTOM_ATTRIBUTES CLOB NULL;
CALL SYSPROC.ADMIN_CMD ('REORG TABLE CONFIGURATION');

ALTER TABLE SCHEDULED_JOB ALTER COLUMN TYPE SET DATA TYPE VARCHAR(255);
CALL SYSPROC.ADMIN_CMD ('REORG TABLE SCHEDULED_JOB');

ALTER TABLE CLASSIFICATION ALTER COLUMN DOMAIN SET DATA TYPE VARCHAR(32);
CALL SYSPROC.ADMIN_CMD ('REORG TABLE CLASSIFICATION');

ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_PRIORITY INT NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_PLANNED TIMESTAMP NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_DUE TIMESTAMP NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_OWNER VARCHAR(32) NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_CLASSIFICATION_NAME VARCHAR(255) NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN ATTACHMENT_CLASSIFICATION_NAME VARCHAR(255) NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN WORKBASKET_NAME VARCHAR(255) NULL;
CALL SYSPROC.ADMIN_CMD ('REORG TABLE TASK_HISTORY_EVENT');

CREATE TABLE USER_INFO (
    USER_ID                     VARCHAR(32)     NOT NULL,
    FIRST_NAME                  VARCHAR(32)     NULL,
    LASTNAME                    VARCHAR(32)     NULL,
    FULL_NAME                   VARCHAR(64)     NULL,
    LONG_NAME                   VARCHAR(64)     NULL,
    E_MAIL                      VARCHAR(64)     NULL,
    PHONE                       VARCHAR(32)     NULL,
    MOBILE_PHONE                VARCHAR(32)     NULL,
    ORG_LEVEL_4                 VARCHAR(32)     NULL,
    ORG_LEVEL_3                 VARCHAR(32)     NULL,
    ORG_LEVEL_2                 VARCHAR(32)     NULL,
    ORG_LEVEL_1                 VARCHAR(32)     NULL,
    DATA                        CLOB            NULL,
    PRIMARY KEY (USER_ID)
);

==> taskana-common-5.10.0-sources.jar: sql/db2/taskana_schema_update_4.3.0_to_4.8.0_db2.sql <==
-- this script updates the TASKANA database schema from version 4.3.0 to version 4.8.0.
-- REORGS are only necessary for _some_ altering operations. See https://www.ibm.com/docs/en/db2/11.1?topic=statements-alter-table
SET SCHEMA %schemaName%;

INSERT INTO TASKANA_SCHEMA_VERSION (VERSION, CREATED) VALUES ('4.8.0', CURRENT_TIMESTAMP);

ALTER TABLE TASK ADD COLUMN RECEIVED TIMESTAMP NULL;
ALTER TABLE TASK ADD COLUMN MANUAL_PRIORITY INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_1 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_2 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_3 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_4 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_5 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_6 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_7 INT NULL;
ALTER TABLE TASK ADD COLUMN CUSTOM_INT_8 INT NULL;

ALTER TABLE CONFIGURATION ADD COLUMN CUSTOM_ATTRIBUTES CLOB NULL;

ALTER TABLE SCHEDULED_JOB ALTER COLUMN TYPE SET DATA TYPE VARCHAR(255);

ALTER TABLE CLASSIFICATION ALTER COLUMN DOMAIN SET DATA TYPE VARCHAR(32);
-- reorg necessary since column has an index defined
CALL SYSPROC.ADMIN_CMD ('REORG TABLE CLASSIFICATION');

ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_PRIORITY INT NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_PLANNED TIMESTAMP NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_DUE TIMESTAMP NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_OWNER VARCHAR(32) NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN TASK_CLASSIFICATION_NAME VARCHAR(255) NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN ATTACHMENT_CLASSIFICATION_NAME VARCHAR(255) NULL;
ALTER TABLE TASK_HISTORY_EVENT ADD COLUMN WORKBASKET_NAME VARCHAR(255) NULL;

CREATE TABLE USER_INFO (
    USER_ID                     VARCHAR(32)     NOT NULL,
    FIRST_NAME                  VARCHAR(32)     NULL,
    LASTNAME                    VARCHAR(32)     NULL,
    FULL_NAME                   VARCHAR(64)     NULL,
    LONG_NAME                   VARCHAR(64)     NULL,
    E_MAIL                      VARCHAR(64)     NULL,
    PHONE                       VARCHAR(32)     NULL,
    MOBILE_PHONE                VARCHAR(32)     NULL,
    ORG_LEVEL_4                 VARCHAR(32)     NULL,
    ORG_LEVEL_3                 VARCHAR(32)     NULL,
    ORG_LEVEL_2                 VARCHAR(32)     NULL,
    ORG_LEVEL_1                 VARCHAR(32)     NULL,
    DATA                        CLOB            NULL,
    PRIMARY KEY (USER_ID)
);
